@@ -20,7 +20,7 @@ $D_NOTME     = 0x10; # return received response not for me
 $D_ANSTOP    = 0x20; # clear run OK flag if ANSWER present
 $D_VERBOSE   = 0x40; # verbose debug statements to STDERR
 
-$VERSION = do { my @r = (q$Revision: 0.13 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.14 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
         run
@@ -275,7 +275,7 @@ A typical configuration line for B<sendmail M4> configuration file is shown
 below:
 
   FEATURE(`dnsbl',`pseudo.dnsbl',
-  `554 Rejected $&{client_addr} found in http://www.spamcannibal.org')dnl
+  `554 Rejected $&{client_addr} found in http://www.my.blacklist.org')dnl
 
 =head1 SYSTEM SIGNALS
 
